@@ -1,9 +1,10 @@
+# frozen_string_literal: true
 module Temple
   module HTML
     # This filter sorts html attributes.
     # @api public
     class AttributeSorter < Filter
-      define_options :sort_attrs => true
+      define_options sort_attrs: true
 
       def call(exp)
         options[:sort_attrs] ? super : exp
